Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DepositProposalRESTHandler ¶
func DepositProposalRESTHandler(cliCtx client.Context) govrest.ProposalRESTHandler
DepositProposalRESTHandler returns a ProposalRESTHandler that exposes the community pool deposit REST handler with a given sub-route.
func WithdrawProposalRESTHandler ¶
func WithdrawProposalRESTHandler(cliCtx client.Context) govrest.ProposalRESTHandler
WithdrawProposalRESTHandler returns a ProposalRESTHandler that exposes the community pool deposit REST handler with a given sub-route.
Types ¶
type CommunityPoolDepositProposalReq ¶
type CommunityPoolDepositProposalReq struct {
BaseReq rest.BaseReq `json:"base_req" yaml:"base_req"`
Title string `json:"title" yaml:"title"`
Description string `json:"description" yaml:"description"`
Amount sdk.Coin `json:"amount" yaml:"amount"`
Deposit sdk.Coins `json:"deposit" yaml:"deposit"`
Proposer sdk.AccAddress `json:"proposer" yaml:"proposer"`
}
CommunityPoolDepositProposalReq defines a community pool deposit proposal request body.
type CommunityPoolWithdrawProposalReq ¶
type CommunityPoolWithdrawProposalReq struct {
BaseReq rest.BaseReq `json:"base_req" yaml:"base_req"`
Title string `json:"title" yaml:"title"`
Description string `json:"description" yaml:"description"`
Amount sdk.Coin `json:"amount" yaml:"amount"`
Deposit sdk.Coins `json:"deposit" yaml:"deposit"`
Proposer sdk.AccAddress `json:"proposer" yaml:"proposer"`
}
CommunityPoolWithdrawProposalReq defines a community pool deposit proposal request body.
Click to show internal directories.
Click to hide internal directories.