Documentation
¶
Index ¶
Constants ¶
const (
// ModuleName name that will be used throughout the module
ModuleName = "swap"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AllowedPool ¶
type AllowedPool struct {
TokenA string `json:"token_a" yaml:"token_a"`
TokenB string `json:"token_b" yaml:"token_b"`
}
AllowedPool defines a tradable pool
type GenesisState ¶
type GenesisState struct {
Params Params `json:"params" yaml:"params"`
PoolRecords `json:"pool_records" yaml:"pool_records"`
}
GenesisState is the state that must be provided at genesis.
type Params ¶
type Params struct {
AllowedPools AllowedPools `json:"allowed_pools" yaml:"allowed_pools"`
SwapFee sdk.Dec `json:"swap_fee" yaml:"swap_fee"`
}
Params are governance parameters for the swap module
type PoolRecord ¶
type PoolRecord struct {
// primary key
PoolID string `json:"pool_id" yaml:"pool_id"`
ReservesA sdk.Coin `json:"reserves_a" yaml:"reserves_a"`
ReservesB sdk.Coin `json:"reserves_b" yaml:"reserves_b"`
}
PoolRecord represents the state of a liquidity pool and is used to store the state of a denominated pool
type ShareRecord ¶
type ShareRecord struct {
Depositor sdk.AccAddress `json:"depositor" yaml:"depositor"`
// secondary / sort key
}
ShareRecord stores the shares owned for a depositor and pool
Click to show internal directories.
Click to hide internal directories.